# FieldOptions11

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**field_id_in_linked_table** | **str** | The id of the field in the linked table | [optional] 
**record_link_field_id** | **str** | The id of the linked field in the same table | [optional] 
**result** | **object** | The computed result of the rollup | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

